==> gwisp-0.0.34.tgz: package/config.js <==
const convict = require('convict')
const path = require('path')

const config = convict({
  verbose: {
    doc: 'log request incomming',
    format: 'int',
    default: 0
  },

  privateKeyPath: {
    doc: 'path to pem encoded private for rsa-sha256',
    format: String,
    default: 'gwisp.key'
  },
  tokenTimeout: {
    doc: 'timeout for access token',
    format: Number,
    default: 3600
  },

  port: {
    doc: 'the port which service listen to',
    format: 'port',
    default: 9001
  },

  dbUrl: {
    doc: 'url to mongodb',
    format: String,
    default: 'mongodb://localhost/gwisp'
  },
  dbUser: {
    doc: 'username to access to mongodb',
    type: String,
    default: null
  },
  dbPass: {
    doc: 'password to access to mongodb',
    type: String,
    default: null
  },

  clientId: {
    doc: 'google oauth-2 client id',
    format: String,
    default: null
  },
  clientSecret: {
    doc: 'google oauth-2 client secret',
    format: String,
    default: null
  },
  redirectUrl: {
    doc: 'url which oauth-2 service will call after successful',
    format: String,
    default: null
  },
  scopes: {
    doc: 'info which application want to access from oauth-2',
    format: Array,
    default: [
      'https://www.googleapis.com/auth/plus.me',
      'profile', 'email'
    ]
  },
  accountUrl: {
    doc: 'url to information of account of oauth provider',
    format: String,
    default: 'https://www.googleapis.com/plus/v1/people/me'
  }
})

config.loadFile('config.json')
var fullPath = path.join(__dirname, config.get('privateKeyPath'))
config.set('privateKeyPath', fullPath)
config.validate({strict: true})

module.exports = config

==> gwisp-0.0.38.tgz: package/config.js <==
const convict = require('convict')
const path = require('path')

const config = convict({
  verbose: {
    doc: 'log request incomming',
    format: 'int',
    default: 0
  },

  privateKeyPath: {
    doc: 'path to pem encoded private for rsa-sha256',
    format: String,
    default: 'gwisp.key'
  },
  tokenTimeout: {
    doc: 'timeout for access token',
    format: Number,
    default: 3600
  },

  port: {
    doc: 'the port which service listen to',
    format: 'port',
    default: 9001
  },

  dbUrl: {
    doc: 'url to mongodb',
    format: String,
    default: 'mongodb://localhost/gwisp'
  },
  dbUser: {
    doc: 'username to access to mongodb',
    type: String,
    default: null
  },
  dbPass: {
    doc: 'password to access to mongodb',
    type: String,
    default: null
  },

  clientId: {
    doc: 'google oauth-2 client id',
    format: String,
    default: null
  },
  clientSecret: {
    doc: 'google oauth-2 client secret',
    format: String,
    default: null
  },
  redirectUrl: {
    doc: 'url which oauth-2 service will call after successful',
    format: String,
    default: null
  },
  scopes: {
    doc: 'info which application want to access from oauth-2',
    format: Array,
    default: [
      'https://www.googleapis.com/auth/plus.me',
      'profile', 'email'
    ]
  },
  accountUrl: {
    doc: 'url to information of account of oauth provider', format: String,
    default: 'https://www.googleapis.com/plus/v1/people/me'
  }
})

config.loadFile('config.json')
var fullPath = path.join(__dirname, config.get('privateKeyPath'))
config.set('privateKeyPath', fullPath)
config.validate({strict: true})

module.exports = config
